﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using Telerik.Web.UI;
using System.Collections;


namespace RadGridExport
{
    public partial class _Default : System.Web.UI.Page
    {
        #region constants
        const string NAME = "NAME";
        const string ID = "ID";
        const int COLCOUNT = 5;
        #endregion

        private RadGrid radGrid = new RadGrid();
        private DataTable dt = null;
        Hashtable selectedIndexesPerPage = null;

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
                ClearSessionIndexHash();

            loadDynamicGrid();

        }

        protected void btnFilter_Click(object sender, EventArgs e)
        {
            Session["isFiltered"] = true;

            SaveSelectedItemsPerPage();
            
            LoadFilteredSelectedItems();
            
            radGrid.CurrentPageIndex = 0;
            radGrid.Rebind();
        }

        private void loadDynamicGrid()
        {
            #region Code for preparing the DataTable

            //Create an instance of DataTable
            dt = new DataTable();

            //Create an ID column for adding to the Datatable
            DataColumn dcol = new DataColumn(ID, typeof(System.Int32));
            dcol.AutoIncrement = true;
            dt.Columns.Add(dcol);


            //Create an ID column for adding to the Datatable
            dcol = new DataColumn(NAME, typeof(System.String));
            dt.Columns.Add(dcol);

            //Let's add some data to the second column.
            for (int nIndex = 0; nIndex < COLCOUNT; nIndex++)
            {
                dcol = new DataColumn("Col" + nIndex.ToString(), typeof(System.String));
                dt.Columns.Add(dcol);
            }

            //Now add data for dynamic columns
            //As the first column is auto-increment, we do not have to add any thing.
            //Let's add some data to the second column.
            for (int nIndex = 0; nIndex < 10; nIndex++)
            {
                //Create a new row
                DataRow drow = dt.NewRow();

                //Initialize the row data.
                drow[NAME] = "Row-" + Convert.ToString((nIndex + 1));

                for (int k = 0; k < COLCOUNT; k++)
                {
                    //Initialize the row data.
                    drow["Col" + k.ToString()] = "Row-" + Convert.ToString((nIndex + 1)) + " Col-" + k.ToString();
                }

                //Add the row to the datatable.
                dt.Rows.Add(drow);
            }
            #endregion


            radGrid.ID = "RadGrid1";
            radGrid.AllowMultiRowSelection = true;
            radGrid.AllowPaging = true;
            radGrid.PageSize = 3;

            radGrid.NeedDataSource += new GridNeedDataSourceEventHandler(radGrid_NeedDataSource);
            radGrid.PageIndexChanged += new GridPageChangedEventHandler(radGrid_PageIndexChanged);
            radGrid.SortCommand += new GridSortCommandEventHandler(radGrid_SortCommand);
            radGrid.PreRender += new EventHandler(radGrid_PreRender);

            radGrid.MasterTableView.DataKeyNames = new string[] { "ID" };
            GridTemplateColumn chkCol = new GridTemplateColumn();
            chkCol.ItemTemplate = new checkBoxItemTemplate();

            radGrid.MasterTableView.Columns.Add(chkCol);

            //Add to the page..
            gridContent.Controls.Add(radGrid);



        }


        void radGrid_PreRender(object sender, EventArgs e)
        {

            if (Session["isFiltered"] != null)
            {
                //radGrid.Rebind();
            }
            else
            {
                //Load the selection items if any..
                LoadSelectedItems();
            }
        }

        void radGrid_SortCommand(object source, GridSortCommandEventArgs e)
        {
            SaveSelectedItemsPerPage();
        }

        void radGrid_PageIndexChanged(object source, GridPageChangedEventArgs e)
        {
            SaveSelectedItemsPerPage();
        }

        void radGrid_NeedDataSource(object source, GridNeedDataSourceEventArgs e)
        {
            if (Session["SelectedItems"] != null)
            {
                radGrid.DataSource = dt.Select("ID in (" + Session["SelectedItems"].ToString() + ")");
            }
            else
            {
                //Set the datasource
                radGrid.DataSource = dt;
            }
        }

        protected void btnExportPDF_Click(object sender, EventArgs e)
        {
            RadGrid radGrid = gridContent.FindControl("RadGrid1") as RadGrid;
            GridTableView masterTable = radGrid.MasterTableView;
            masterTable.Style["font-size"] = "4pt";
            masterTable.Style["font-family"] = "Arial Narrow";
            masterTable.BorderStyle = BorderStyle.None;
            radGrid.BorderStyle = BorderStyle.None;

            radGrid.ExportSettings.Pdf.PageLeftMargin = Unit.Parse("10mm");
            radGrid.ExportSettings.Pdf.PageRightMargin = Unit.Parse("10mm");

            radGrid.ExportSettings.Pdf.PageWidth = Unit.Parse("297mm");
            radGrid.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");

            radGrid.ExportSettings.ExportOnlyData = true;
            radGrid.ExportSettings.OpenInNewWindow = true;
            radGrid.MasterTableView.ExportToPdf();
        }

        private void SaveSelectedItemsPerPage()
        {
            Hashtable selectedHash = GetSessionIndexHash();

            ArrayList lstSelectedIndexes = new ArrayList();

            GridItemCollection selItems = radGrid.SelectedItems;

            foreach (GridItem item in radGrid.SelectedItems)
            {
                lstSelectedIndexes.Add(item.ItemIndex.ToString() + ":" + (item as GridDataItem).GetDataKeyValue("ID"));
            }

            if (lstSelectedIndexes.Count > 0)
            {
                selectedHash[radGrid.MasterTableView.CurrentPageIndex] = lstSelectedIndexes;
            }

            Session["selectedIndexesPerPage"] = selectedHash;
        }

        private void LoadSelectedItems()
        {
            Hashtable selectedHash = GetSessionIndexHash();
            if (selectedHash != null && selectedHash.Count > 0)
            {
                ArrayList lstSelectedItem = (ArrayList)selectedHash[radGrid.CurrentPageIndex];

                for (int i = 0; ((lstSelectedItem != null) && (i < lstSelectedItem.Count)); i++)
                {
                    int itemIndex = int.Parse(lstSelectedItem[i].ToString().Split(':')[0]);
                    GridDataItem dataItem = radGrid.MasterTableView.Items[itemIndex];
                    //CheckBox chkBox = (CheckBox)dataItem.FindControl("chkBox" + dataItem.RowIndex.ToString());
                    CheckBox chkBox = (CheckBox)dataItem.FindControl("chkBox1");


                    if (chkBox != null)
                        chkBox.Checked = true;

                    dataItem.Selected = true;
                }
            }
        }        
        private void LoadFilteredSelectedItems()
        {
            Hashtable selectedHash = GetSessionIndexHash();
            if (selectedHash != null && selectedHash.Count > 0)
            {
                string lstSelectedItem = "";
                foreach (int pageIndex in selectedHash.Keys)
                {
                    for (int j = 0; j < (selectedHash[pageIndex] as ArrayList).Count; j++)
                    {
                        lstSelectedItem += (selectedHash[pageIndex] as ArrayList)[j].ToString().Split(':')[1] + ",";
                    }
                }
                lstSelectedItem = lstSelectedItem.Substring(0, lstSelectedItem.Length - 1);
                Session["SelectedItems"] = lstSelectedItem;
            }            
        }

        private Hashtable GetSessionIndexHash()
        {
            if ((Session["selectedIndexesPerPage"] == null))
            {
                selectedIndexesPerPage = new Hashtable();
            }
            else
            {
                selectedIndexesPerPage = ((Hashtable)(Session["selectedIndexesPerPage"]));
            }

            return selectedIndexesPerPage;
        }

        private void ClearSessionIndexHash()
        {
            Session["selectedIndexesPerPage"] = null;
        }

    }

    public class checkBoxItemTemplate : ITemplate
    {
        public void InstantiateIn(System.Web.UI.Control container)
        {
            CheckBox chkBox = new CheckBox();
            chkBox.AutoPostBack = true;

            GridDataItem dataItem = (GridDataItem)chkBox.NamingContainer;
            chkBox.ID = "chkBox1";

            chkBox.CheckedChanged += new EventHandler(chkBox_CheckedChanged);

            container.Controls.Add(chkBox);
        }

        void chkBox_CheckedChanged(object sender, EventArgs e)
        {
            CheckBox chkB = (CheckBox)sender;
            GridDataItem dataItem = (GridDataItem)chkB.NamingContainer;

            dataItem.Selected = chkB.Checked;
        }
    }
}
